@@ -6,7 +6,7 @@ This file is part of the GNU MP Library.
 
 The GNU MP Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MP Library is distributed in the hope that it will be useful, but
@@ -15,9 +15,7 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA. */
+along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
 #include "gmp.h"
 #include "gmp-impl.h"
@@ -69,6 +67,7 @@ int arr[GMP_LIMB_BITS + 1];
 
 
 /* One-limb division optimized for small quotients.  */
+#if 0
 static mp_limb_t
 div1 (mp_limb_t n0, mp_limb_t d0)
 {
@@ -121,6 +120,7 @@ div1 (mp_limb_t n0, mp_limb_t d0)
       return q;
     }
 }
+#endif
 
 /* Two-limb division optimized for small quotients.  */
 static mp_limb_t
@@ -202,7 +202,7 @@ mpn_gcd (mp_ptr gp,
   int sign = 1;
 #endif
   int use_double_flag;
-  TMP_DECL (mark);
+  TMP_DECL;
 
   ASSERT (size >= vsize);
   ASSERT (vsize >= 1);
@@ -216,7 +216,7 @@ mpn_gcd (mp_ptr gp,
   ASSERT (MPN_SAME_OR_SEPARATE_P (gp, up, size));
   ASSERT (MPN_SAME_OR_SEPARATE2_P (gp, size, vp, vsize));
 
-  TMP_MARK (mark);
+  TMP_MARK;
 
   tp = (mp_ptr) TMP_ALLOC ((size + 1) * BYTES_PER_MP_LIMB);
   wp = (mp_ptr) TMP_ALLOC ((size + 1) * BYTES_PER_MP_LIMB);
@@ -662,7 +662,7 @@ mpn_gcd (mp_ptr gp,
 	}
 
 #if WANT_GCDEXT_ONE_STEP
-      TMP_FREE (mark);
+      TMP_FREE;
       return 0;
 #endif
     }
@@ -685,7 +685,7 @@ mpn_gcd (mp_ptr gp,
 	MPN_COPY (orig_s0p, s0p, ssize);
       *s0size = sign >= 0 ? ssize : -ssize;
 #endif
-      TMP_FREE (mark);
+      TMP_FREE;
       return size;
     }
   else
@@ -771,7 +771,7 @@ mpn_gcd (mp_ptr gp,
 	MPN_COPY (orig_s0p, s0p, ssize);
       *s0size = sign >= 0 ? ssize : -ssize;
 #endif
-      TMP_FREE (mark);
+      TMP_FREE;
       return 1;
     }
 }
